/* zenith_theme.h - Zenith GTK Theme header file.
** Copyright (C) 1999 Karl J. Ots.
** 
** This library is free software; you can redistribute it and/or
** modify it under the terms of the GNU Library General Public
** License as published by the Free Software Foundation; either
** version 2 of the License, or (at your option) any later version.
** 
** This library is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
** Library General Public License for more details.
** 
** You should have received a copy of the GNU Library General Public
** License along with this library; if not, write to the
** Free Software Foundation, Inc., 59 Temple Place - Suite 330,
** Boston, MA 02111-1307, USA.
*/

#ifndef __KJO__ZENITH_THEME_H
#define __KJO__ZENITH_THEME_H

#include <gtk/gtk.h>

typedef enum {
  ZENITH_HSB_FORM_NORMAL,
  ZENITH_HSB_FORM_LEFT,
  ZENITH_HSB_FORM_RIGHT
} ZenithHSBForm;
  
typedef enum {
  ZENITH_VSB_FORM_NORMAL,
  ZENITH_VSB_FORM_TOP,
  ZENITH_VSB_FORM_BOTTOM
} ZenithVSBForm;

typedef enum {
  ZENITH_SB_PLACE_TOP_LEFT,
  ZENITH_SB_PLACE_TOP_RIGHT,
  ZENITH_SB_PLACE_BOTTOM_LEFT,
  ZENITH_SB_PLACE_BOTTOM_RIGHT,
} ZenithSBPlace;

typedef enum {
  ZENITH_SB_INDENT_NONE,
  ZENITH_SB_INDENT_HORIZONTAL,
  ZENITH_SB_INDENT_VERTICAL
} ZenithSBIndent;
  

#define ZENITH_SB_PLACE_TOP(p)    (((p) == ZENITH_SB_PLACE_TOP_LEFT)    || ((p) == ZENITH_SB_PLACE_TOP_RIGHT))
#define ZENITH_SB_PLACE_BOTTOM(p) (((p) == ZENITH_SB_PLACE_BOTTOM_LEFT) || ((p) == ZENITH_SB_PLACE_BOTTOM_RIGHT))
#define ZENITH_SB_PLACE_LEFT(p)   (((p) == ZENITH_SB_PLACE_TOP_LEFT)    || ((p) == ZENITH_SB_PLACE_BOTTOM_LEFT))
#define ZENITH_SB_PLACE_RIGHT(p)  (((p) == ZENITH_SB_PLACE_TOP_RIGHT)   || ((p) == ZENITH_SB_PLACE_BOTTOM_RIGHT))

/*
** Information about an instance of this theme.
*/
typedef struct _ZenithThemeData {
  guint          refcount;         /* Reference count for an instance      */

  gint           contrast;         /* Conrast for 3D effects               */
  ZenithHSBForm  hsb_form;         /* Form of the horizontal scrollbar     */
  ZenithVSBForm  vsb_form;         /* Form of the vertical scrollbar       */
  ZenithSBPlace  sb_place;         /* Scrollbar place in scrolled windows  */
  ZenithSBIndent sb_indent;        /* Indent a scrollbar into the gap      */
  gboolean       hide_sb;          /* Hide scrollbars?                     */
  
  /* Extra colours */
  GdkColor       half_light[5];    /* Colours halfway between bg and light */
  GdkColor       half_dark[5];     /* Colours halfway between bg and dark  */
  GdkGC         *half_light_gc[5]; /* Graphics Contexts for half_light     */
  GdkGC         *half_dark_gc[5];  /* Graphics Contexts for half_dark      */
} ZenithThemeData;

#endif /* __KJO__ZENITH_THEME_H */
